EncExp (Encaje Explicable)
====================================

.. image:: https://coveralls.io/repos/github/INGEOTEC/EncExp/badge.svg?branch=develop
    :target: https://coveralls.io/github/INGEOTEC/EncExp?branch=develop

EncExp is a set of tools to create and use explainable embeddings.